Apply .clangformat to all repo source files

Change-Id: I7e79c6058f0303f9a98911e3b7dd2e8596079344


[ROCm/hip-tests commit: 6b09bde675]
This commit is contained in:
Maneesh Gupta
2018-03-12 11:29:03 +05:30
parent dd60eaa156
commit 3277453ea5
39 changed files with 2386 additions and 2967 deletions
@@ -22,8 +22,7 @@ THE SOFTWARE.
#include "hip/hip_runtime.h"
extern "C" __global__ void hello_world(float *a, float *b)
{
extern "C" __global__ void hello_world(float* a, float* b) {
int tx = hipThreadIdx_x;
b[tx] = a[tx];
}